@@ -338,8 +338,6 @@ class Help(SpyderPluginWidget):
 
         self.internal_shell = None
         self.console = None
-        self.ipyconsole = None
-        self.editor = None
 
         # Initialize plugin
         self.initialize_plugin()
@@ -507,8 +505,6 @@ class Help(SpyderPluginWidget):
 
         self.internal_shell = self.main.console.shell
         self.console = self.main.console
-        self.ipyconsole = self.main.ipyconsole
-        self.editor = self.main.editor
 
     def closing_plugin(self, cancelable=False):
         """Perform actions before parent main window is closed"""
@@ -549,8 +545,8 @@ class Help(SpyderPluginWidget):
             self.toggle_math_mode(math_o)
 
         # To make auto-connection changes take place instantly
-        self.editor.apply_plugin_settings(options=[connect_n])
-        self.ipyconsole.apply_plugin_settings(options=[connect_n])
+        self.main.editor.apply_plugin_settings(options=[connect_n])
+        self.main.ipyconsole.apply_plugin_settings(options=[connect_n])
 
     #------ Public API (related to Help's source) -------------------------
     def source_is_console(self):
@@ -821,8 +817,8 @@ class Help(SpyderPluginWidget):
                     (force or text != self._last_texts[index])):
                 dockwidgets = self.main.tabifiedDockWidgets(self.dockwidget)
                 if (self.console.dockwidget not in dockwidgets and
-                        self.ipyconsole is not None and
-                        self.ipyconsole.dockwidget not in dockwidgets):
+                        self.main.ipyconsole is not None and
+                        self.main.ipyconsole.dockwidget not in dockwidgets):
                     self.dockwidget.show()
                     self.dockwidget.raise_()
         self._last_texts[index] = text
@@ -904,8 +900,8 @@ class Help(SpyderPluginWidget):
                 (hasattr(self.shell, 'is_running') and
                  not self.shell.is_running())):
             self.shell = None
-            if self.ipyconsole is not None:
-                shell = self.ipyconsole.get_current_shellwidget()
+            if self.main.ipyconsole is not None:
+                shell = self.main.ipyconsole.get_current_shellwidget()
                 if shell is not None and shell.kernel_client is not None:
                     self.shell = shell
             if self.shell is None:
@@ -915,8 +911,8 @@ class Help(SpyderPluginWidget):
     def render_sphinx_doc(self, doc, context=None):
         """Transform doc string dictionary to HTML and show it"""
         # Math rendering option could have changed
-        if self.editor is not None:
-            fname = self.editor.get_current_filename()
+        if self.main.editor is not None:
+            fname = self.main.editor.get_current_filename()
             dname = osp.dirname(fname)
         else:
             dname = ''
