@@ -7,6 +7,8 @@
 """Simple web browser widget"""
 
 # Standard library imports
+import re
+import sre_constants
 import sys
 
 # Third party imports
@@ -21,7 +23,8 @@ from qtpy.QtGui import QFontInfo
 from spyder.config.base import _, DEV
 from spyder.py3compat import is_text_string, to_text_string
 from spyder.utils.qthelpers import (action2button, add_actions,
-                                    create_action, create_toolbutton)
+                                    create_action, create_toolbutton,
+                                    create_plugin_layout)
 from spyder.utils import icon_manager as ima
 from spyder.widgets.comboboxes import UrlComboBox
 from spyder.widgets.findreplace import FindReplace
@@ -61,6 +64,7 @@ class WebView(QWebEngineView):
         if WEBENGINE:
             web_page = WebPage(self)
             self.setPage(web_page)
+            self.source_text = ''
 
     def find_text(self, text, changed=True,
                   forward=True, case=False, words=False,
@@ -81,7 +85,40 @@ class WebView(QWebEngineView):
     def get_selected_text(self):
         """Return text selected by current text cursor"""
         return self.selectedText()
-        
+
+    def set_source_text(self, source_text):
+        """Set source text of the page. Callback for QWebEngineView."""
+        self.source_text = source_text
+
+    def get_number_matches(self, pattern, source_text='', case=False,
+                           regexp=False):
+        """Get the number of matches for the searched text."""
+        pattern = to_text_string(pattern)
+        if not pattern:
+            return 0
+        if not regexp:
+            pattern = re.escape(pattern)
+        if not source_text:
+            if WEBENGINE:
+                self.page().toPlainText(self.set_source_text)
+                source_text = to_text_string(self.source_text)
+            else:
+                source_text = to_text_string(
+                        self.page().mainFrame().toPlainText())
+        try:
+            if case:
+                regobj = re.compile(pattern)
+            else:
+                regobj = re.compile(pattern, re.IGNORECASE)
+        except sre_constants.error:
+            return
+
+        number_matches = 0
+        for match in regobj.finditer(source_text):
+            number_matches += 1
+
+        return number_matches
+
     def set_font(self, font, fixed_font=None):
         font = QFontInfo(font)
         settings = self.page().settings()
@@ -222,8 +259,7 @@ class WebBrowser(QWidget):
                        refresh_button, progressbar, stop_button):
             hlayout.addWidget(widget)
         
-        layout = QVBoxLayout()
-        layout.addLayout(hlayout)
+        layout = create_plugin_layout(hlayout)
         layout.addWidget(self.webview)
         layout.addWidget(self.find_widget)
         self.setLayout(layout)
