@@ -80,7 +80,7 @@ def create_script(fname):
     encoding.write(to_text_string(text), fname, 'utf-8')
 
 
-def listdir(path, include='.', exclude=r'\.pyc$|^\.', show_all=False,
+def listdir(path, include=r'.', exclude=r'\.pyc$|^\.', show_all=False,
             folders_only=False):
     """List files and directories"""
     namelist = []
@@ -153,7 +153,16 @@ class IconProvider(QFileIconProvider):
                     icon = ima.icon(self.OFFICE_FILES[extension])
 
                 if mime_type is not None:
-                    file_type, bin_name = mime_type.split('/')
+                    try:
+                        # Fix for issue 5080.  Even though mimetypes.guess_type
+                        # documentation states that the return value will be
+                        # None or a tuple of the form type/subtype, in the
+                        # Windows registry, .sql has a mimetype of text\plain
+                        # instead of text/plain therefore mimetypes is
+                        # returning it incorrectly.
+                        file_type, bin_name = mime_type.split('/')
+                    except ValueError:
+                        file_type = 'text'
                     if file_type == 'text':
                         icon = ima.icon('TextFileIcon')
                     elif file_type == 'audio':
@@ -659,7 +668,10 @@ class DirView(QTreeView):
                     return
             try:
                 misc.rename_file(fname, path)
-                self.parent_widget.renamed.emit(fname, path)
+                if osp.isfile(fname):
+                    self.parent_widget.renamed.emit(fname, path)
+                else:
+                    self.parent_widget.renamed_tree.emit(fname, path)
                 return path
             except EnvironmentError as error:
                 QMessageBox.critical(self, _("Rename"),
@@ -685,14 +697,18 @@ class DirView(QTreeView):
             self.rename_file(fname)
 
     @Slot()
-    def move(self, fnames=None):
+    def move(self, fnames=None, directory=None):
         """Move files/directories"""
         if fnames is None:
             fnames = self.get_selected_filenames()
         orig = fixpath(osp.dirname(fnames[0]))
         while True:
             self.parent_widget.redirect_stdio.emit(False)
-            folder = getexistingdirectory(self, _("Select directory"), orig)
+            if directory is None:
+                folder = getexistingdirectory(self, _("Select directory"),
+                                              orig)
+            else:
+                folder = directory
             self.parent_widget.redirect_stdio.emit(True)
             if folder:
                 folder = fixpath(folder)
