@@ -122,11 +122,7 @@ def test_collectionsmodel_with_datetimeindex():
     assert data(cm, 0, 0) == 'rng'
     assert data(cm, 0, 1) == 'DatetimeIndex'
     assert data(cm, 0, 2) == '(25,)' or data(cm, 0, 2) == '(25L,)'
-    try:
-        assert data(cm, 0, 3) == rng._summary()
-    except AttributeError:
-        assert data(cm, 0, 3) == rng.summary()
-
+    assert data(cm, 0, 3) == rng.summary()
 
 def test_shows_dataframeeditor_when_editing_datetimeindex(qtbot, monkeypatch):
     MockDataFrameEditor = Mock()
